# MailMojo SDK for Python
v1 of the MailMojo API

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.1.0
- Package version: 0.3.3
- Build package: io.swagger.codegen.languages.PythonClientCodegen

For more information, please visit [https://mailmojo.gelato.io](https://mailmojo.gelato.io)

## Requirements

Python 2.7 and 3.4+

## Installation & Usage
### pip install

We recommend you install with pip:

```sh
pip install mailmojo-sdk
```

Then import the package:
```python
import mailmojo_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools) is also possible.

Clone the repo and perform the installation:

```sh
git clone https://github.com/eliksir/mailmojo-python-sdk.git
cd mailmojo-python-sdk
python setup.py install --user
```

(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import mailmojo_sdk
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import mailmojo_sdk
from mailmojo_sdk.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: mailmojo_auth
configuration = mailmojo_sdk.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = mailmojo_sdk.AccountApi(mailmojo_sdk.ApiClient(configuration))
user = mailmojo_sdk.MinimalUser() # MinimalUser | 

try:
    # Create an account.
    api_response = api_instance.create_account(user)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AccountApi->create_account: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.mailmojo.no/v1*

Class | Method | HTTP request | Description
--- | --- | --- | ---
*AccountApi* | [create_account](docs/AccountApi.md#create_account) | **POST** /accounts/ | Create an account.
*AccountApi* | [get_account_by_username](docs/AccountApi.md#get_account_by_username) | **GET** /accounts/{username}/ | Retrieve account details.
*AccountApi* | [update_account](docs/AccountApi.md#update_account) | **POST** /accounts/{username}/ | Update account details.
*AutomationApi* | [get_campaign_by_id](docs/AutomationApi.md#get_campaign_by_id) | **GET** /campaigns/{campaign_id}/ | Retrieve an automation campaign by id.
*ContactApi* | [get_contacts](docs/ContactApi.md#get_contacts) | **GET** /contacts/ | Retrieve all contacts across every list.
*ContactApi* | [get_subscriber_on_list_by_email](docs/ContactApi.md#get_subscriber_on_list_by_email) | **GET** /lists/{list_id}/subscribers/{email}/ | Retrieve a subscriber.
*ContactApi* | [get_subscribers_on_list](docs/ContactApi.md#get_subscribers_on_list) | **GET** /lists/{list_id}/subscribers/ | Retrieve subscribers on a list.
*ContactApi* | [subscribe_contact_to_list](docs/ContactApi.md#subscribe_contact_to_list) | **POST** /lists/{list_id}/subscribers/ | Subscribe a contact to the email list.
*ContactApi* | [unsubscribe_contact_on_list_by_email](docs/ContactApi.md#unsubscribe_contact_on_list_by_email) | **DELETE** /lists/{list_id}/subscribers/{email}/ | Unsubscribe a contact.
*ContactApi* | [update_contact](docs/ContactApi.md#update_contact) | **PATCH** /contacts/{email}/ | Update details about a contact.
*EmbedApi* | [create_embed_session](docs/EmbedApi.md#create_embed_session) | **POST** /embed/ | Create a new embedded application session.
*ListApi* | [get_list_by_id](docs/ListApi.md#get_list_by_id) | **GET** /lists/{list_id}/ | Retrieve an email list.
*ListApi* | [get_lists](docs/ListApi.md#get_lists) | **GET** /lists/ | Retrieve all email lists.
*ListApi* | [get_subscriber_on_list_by_email](docs/ListApi.md#get_subscriber_on_list_by_email) | **GET** /lists/{list_id}/subscribers/{email}/ | Retrieve a subscriber.
*ListApi* | [get_subscribers_on_list](docs/ListApi.md#get_subscribers_on_list) | **GET** /lists/{list_id}/subscribers/ | Retrieve subscribers on a list.
*ListApi* | [import_subscribers_to_list](docs/ListApi.md#import_subscribers_to_list) | **POST** /lists/{list_id}/subscribers/import/ | Subscribe contacts to the email list.
*ListApi* | [subscribe_contact_to_list](docs/ListApi.md#subscribe_contact_to_list) | **POST** /lists/{list_id}/subscribers/ | Subscribe a contact to the email list.
*ListApi* | [unsubscribe_contact_on_list_by_email](docs/ListApi.md#unsubscribe_contact_on_list_by_email) | **DELETE** /lists/{list_id}/subscribers/{email}/ | Unsubscribe a contact.
*ListApi* | [update_list](docs/ListApi.md#update_list) | **PATCH** /lists/{list_id}/ | Update an email list partially.
*NewsletterApi* | [create_newsletter](docs/NewsletterApi.md#create_newsletter) | **POST** /newsletters/ | Create a newsletter draft.
*NewsletterApi* | [get_newsletter_by_id](docs/NewsletterApi.md#get_newsletter_by_id) | **GET** /newsletters/{newsletter_id}/ | Retrieve a newsletter by id.
*NewsletterApi* | [get_newsletters](docs/NewsletterApi.md#get_newsletters) | **GET** /newsletters/ | Retrieve all newsletters.
*NewsletterApi* | [send_newsletter](docs/NewsletterApi.md#send_newsletter) | **PUT** /newsletters/{newsletter_id}/send/ | Send a newsletter.
*NewsletterApi* | [test_newsletter](docs/NewsletterApi.md#test_newsletter) | **POST** /newsletters/{newsletter_id}/send_test/ | Send a test newsletter.


## Documentation For Models

 - [CampaignDetail](docs/CampaignDetail.md)
 - [CampaignDetailStatistics](docs/CampaignDetailStatistics.md)
 - [Contact](docs/Contact.md)
 - [ContactListAssociations](docs/ContactListAssociations.md)
 - [Contacts](docs/Contacts.md)
 - [Embed](docs/Embed.md)
 - [EmbedOptions](docs/EmbedOptions.md)
 - [ImportResult](docs/ImportResult.md)
 - [List](docs/List.md)
 - [MinimalContact](docs/MinimalContact.md)
 - [MinimalUser](docs/MinimalUser.md)
 - [Newsletter](docs/Newsletter.md)
 - [NewsletterCreation](docs/NewsletterCreation.md)
 - [NewsletterSegments](docs/NewsletterSegments.md)
 - [NewsletterSend](docs/NewsletterSend.md)
 - [NewsletterSendTest](docs/NewsletterSendTest.md)
 - [NewsletterStatistics](docs/NewsletterStatistics.md)
 - [PageMeta](docs/PageMeta.md)
 - [PaginatedResult](docs/PaginatedResult.md)
 - [Subscriber](docs/Subscriber.md)
 - [User](docs/User.md)


## Documentation For Authorization


## mailmojo_auth

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://api.mailmojo.no/oauth/authorize/
- **Scopes**: 
  - **account**: Manage your MailMojo account.
  - **account_creation**: Create new MailMojo accounts.
  - **account_creation.trial_30**: Create new MailMojo accounts with a 30 day trial period.
  - **campaigns:read**: Retrieve your automated campaigns.
  - **contacts**: Manage your contacts across all your email lists.
  - **contacts:read**: Retrieve your contacts across all your email lists.
  - **embed**: Give you an embedded MailMojo application with access to your account.
  - **lists**: Manage your email lists, excluding subscribers.
  - **lists:read**: Retrieve your email lists, excluding subscribers.
  - **newsletters**: Manage your newsletters.
  - **newsletters:read**: Retrieve your newsletters.


## Author

hjelp@mailmojo.no

